@@ -9,135 +9,136 @@ use Archive::Har::Page();
 use Archive::Har::Entry();
 use JSON();
 use Carp();
-use overload '""' => "string";
+use overload '""' => 'string';
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
-	my ($class, $params) = @_;
-	my $self = {};
-	$self->{log} = {};
-	$self->{_raise_error} = 1;
-	if ((defined $params->{_raise_error}) && ($params->{_raise_error} == 0)) {
-		$self->{_raise_error} = 0;
-	}
-	bless $self, $class;
-	return $self;
+    my ( $class, $params ) = @_;
+    my $self = {};
+    $self->{log} = {};
+    bless $self, $class;
+    return $self;
 }
 
 sub string {
-	my ($self, $string) = @_;
-	my $old = JSON->new()->utf8()->allow_blessed(1)->convert_blessed(1)->pretty()->encode($self);
-	if ((@_ > 1) && (defined $string)) {
-		my $ref = JSON->new()->utf8()->decode($string);
-		$self->version($ref->{log}->{version});
-		$self->creator($ref->{log}->{creator});
-		if (defined $ref->{log}->{browser}) {
-			$self->browser($ref->{log}->{browser});
-		}
-		$self->pages($ref->{log}->{pages});
-		$self->entries($ref->{log}->{entries});
-		$self->comment($ref->{log}->{comment});
-	}
-	return $old;
-}
-
-sub error {
-	my ($self, $error) = @_;
-	my $old = $self->{_error};
-	if (@_ > 1) {
-		$self->{_error} = $error;
-		if ($self->{_raise_error}) {
-			Carp::croak($error);
-		}
-	}
-	return $old;
+    my ( $self, $string ) = @_;
+    my $old =
+      JSON->new()->utf8()->allow_blessed(1)->convert_blessed(1)->pretty()
+      ->encode($self);
+    if ( ( @_ > 1 ) && ( defined $string ) ) {
+        my $ref = JSON->new()->utf8()->decode($string);
+        $self->version( $ref->{log}->{version} );
+        $self->creator( Archive::Har::Creator->new( $ref->{log}->{creator} ) );
+        if ( defined $ref->{log}->{browser} ) {
+            $self->browser(
+                Archive::Har::Browser->new( $ref->{log}->{browser} ) );
+        }
+        if ( defined $ref->{log}->{pages} ) {
+            $self->pages( $ref->{log}->{pages} );
+        }
+        $self->entries( $ref->{log}->{entries} );
+        $self->comment( $ref->{log}->{comment} );
+    }
+    return $old;
 }
 
 sub version {
-	my ($self, $version) = @_;
-	my $old = $self->{log}->{version} || '1.1';
-	if (@_ > 1) {
-		$self->{log}->{version} = $version;
-	}
-	return $old;
+    my ( $self, $new ) = @_;
+    my $old = $self->{log}->{version};
+    if ( @_ > 1 ) {
+        $self->{log}->{version} = $new;
+    }
+    if ( defined $old ) {
+        return $old;
+    }
+    else {
+        return '1.1';
+    }
 }
 
 sub creator {
-	my ($self, $creator) = @_;
-	my $old = $self->{log}->{creator} || Archive::Har::Creator->new();
-	if (@_ > 1) {
-		$self->{log}->{creator} = Archive::Har::Creator->new($creator);
-	}
-	return $old;
+    my ( $self, $new ) = @_;
+    my $old = $self->{log}->{creator};
+    if ( @_ > 1 ) {
+        $self->{log}->{creator} = $new;
+    }
+    return $old;
 }
 
 sub browser {
-	my ($self, $browser) = @_;
-	my $old = $self->{log}->{browser};
-	if (@_ > 1) {
-		$self->{log}->{browser} = Archive::Har::Browser->new($browser);
-	}
-	return $old;
+    my ( $self, $new ) = @_;
+    my $old = $self->{log}->{browser};
+    if ( @_ > 1 ) {
+        $self->{log}->{browser} = $new;
+    }
+    return $old;
 }
 
 sub pages {
-	my ($self, $pages) = @_;
-	my $old = $self->{log}->{pages} || [];
-	if (@_ > 1) {
-		$self->{log}->{pages} = [];
-		my $page_count = 0;
-		foreach my $page (@{$pages}) {
-			if (!defined $page->{id}) {
-				$page->{id} = 'page_' . $page_count;
-			}
-			push @{$self->{log}->{pages}}, Archive::Har::Page->new($page);
-			$page_count += 1;
-		}
-	}
-	return @{$old};
+    my ( $self, $new ) = @_;
+    my $old = $self->{log}->{pages};
+    if ( @_ > 1 ) {
+        if ( defined $new ) {
+            $self->{log}->{pages} = [];
+            my $page_count = 0;
+            foreach my $page ( @{$new} ) {
+                if ( !defined $page->{id} ) {
+                    $page->{id} = 'page_' . $page_count;
+                }
+                push @{ $self->{log}->{pages} }, Archive::Har::Page->new($page);
+                $page_count += 1;
+            }
+        }
+    }
+    if ( defined $old ) {
+        return @{$old};
+    }
+    else {
+        return ();
+    }
 }
 
 sub entries {
-	my ($self, $entries) = @_;
-	my $old = $self->{log}->{entries} || [];
-	if (@_ > 1) {
-		$self->{log}->{entries} = [];
-		foreach my $entry (@{$entries}) {
-			push @{$self->{log}->{entries}}, Archive::Har::Entry->new($entry);
-		}
-	}
-	return @{$old};
+    my ( $self, $entries ) = @_;
+    my $old = $self->{log}->{entries} || [];
+    if ( @_ > 1 ) {
+        $self->{log}->{entries} = [];
+        foreach my $entry ( @{$entries} ) {
+            push @{ $self->{log}->{entries} }, Archive::Har::Entry->new($entry);
+        }
+    }
+    return @{$old};
 }
 
 sub comment {
-	my ($self, $comment) = @_;
-	my $old = $self->{log}->{comment};
-	if (@_ > 1) {
-		$self->{log}->{comment} = $comment;
-	}
-	return $old;
+    my ( $self, $comment ) = @_;
+    my $old = $self->{log}->{comment};
+    if ( @_ > 1 ) {
+        $self->{log}->{comment} = $comment;
+    }
+    return $old;
 }
 
 sub TO_JSON {
-	my ($self) = @_;
-	my $json = {};
-        $json->{version} = $self->version();
-	$json->{creator} = $self->creator();
-	if (defined $self->browser()) {
-		$json->{browser} = $self->browser();
-	}
-	if (defined $self->pages()) {
-		$json->{pages} = [ $self->pages() ];
-	}
-	$json->{entries} = [ $self->entries() ];
-	if (defined $self->comment()) {
-		$json->{comment} = $self->comment();
-	}
-	return { log => $json };
+    my ($self) = @_;
+    my $json = {};
+    $json->{version} = $self->version();
+    $json->{creator} = $self->creator();
+    if ( defined $self->browser() ) {
+        $json->{browser} = $self->browser();
+    }
+    if ( defined $self->pages() ) {
+        $json->{pages} = [ $self->pages() ];
+    }
+    $json->{entries} = [ $self->entries() ];
+    if ( defined $self->comment() ) {
+        $json->{comment} = $self->comment();
+    }
+    return { log => $json };
 }
 
-1; # End of Archive::Har
+1;    # End of Archive::Har
 __END__
 =head1 NAME
 
@@ -145,7 +146,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -174,10 +175,6 @@ Archive::Har->new() will return a new har object, ready to process http archives
 
 $har->string() accepts a stringified version of an http archive and parses it.  It returns the previous state of the archive in stringified form
 
-=head2 error
-
-$har->error() will return the most recent error message generated by $har
-
 =head2 version
 
 $har->version() will return the version of the HTTP Archive ('1.1' by default);
