@@ -8,7 +8,7 @@ use Archive::Har::Entry::Response();
 use Archive::Har::Entry::Cache();
 use Archive::Har::Entry::Timings();
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ($class, $params) = @_;
@@ -34,9 +34,7 @@ sub new {
 		}
 		foreach my $key (sort { $a cmp $b } keys %{$params}) {
 			if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
-				if (defined $params->{$key}) {
-					$self->$key($params->{$key});
-				}
+				$self->$key($params->{$key});
 			}
 		}
 	}
@@ -63,7 +61,7 @@ sub started_date_time {
 			if ($new =~ /^${date_regex}T${time_regex}${zone_regex}$/smx) {
 				$self->{startedDateTime} = $new;
 			} else {
-				Carp::croak("started_date_time is not formatted correctly:$new");
+				Carp::croak("started_date_time is not formatted correctly");
 			}
 		}
 	}
@@ -72,35 +70,30 @@ sub started_date_time {
 	} else {
 		return '0000-00-00T00:00:00.0+00:00';
 	}
-	return $old;
 }
 
 sub time {
 	my ($self) = @_;
         my $timings = $self->timings();
-	if (defined $timings) {
-		my $total = 0;
-		my $found = 0;
-		foreach my $timing (
-						$timings->blocked(),
-						$timings->dns(),
-						$timings->connect(),
-						$timings->send(),
-						$timings->wait(),
-						$timings->receive(),
-						$timings->ssl(),
-					)
-		{
-			if (defined $timing) {
-				$found = 1;
-				$total += $timing;
-			}
-		}
-		if ($found) {
-			return $total;
-		} else {
-			return -1;
+	my $total = 0;
+	my $found = 0;
+	foreach my $timing (
+					$timings->blocked(),
+					$timings->dns(),
+					$timings->connect(),
+					$timings->send(),
+					$timings->wait(),
+					$timings->receive(),
+					$timings->ssl(),
+				)
+	{
+		if (defined $timing) {
+			$found = 1;
+			$total += $timing;
 		}
+	}
+	if ($found) {
+		return $total;
 	} else {
 		return -1;
 	}
@@ -187,21 +180,20 @@ sub comment {
 
 sub AUTOLOAD {
 	my ($self, $new) = @_;
-	my $type = ref $self or Carp::croak("$self is not an object");
 
 	my $name = $Archive::Har::Entry::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
+	my $old;
 	if ($name =~ /^_[[:alnum:]]+$/smx) { # private fields
-		my $old = $self->{$name};
+		$old = $self->{$name};
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
-	return;
+	return $old;
 }
 
 sub TO_JSON {
@@ -242,7 +234,7 @@ Archive::Har::Entry - Represents a single http request/response pair inside the
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -266,6 +258,10 @@ Version 0.07
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Entry object
+
 =head2 pageref
 
 returns the reference to the parent page.  This may be null.
