@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ($class, $params) = @_;
@@ -26,9 +26,7 @@ sub new {
 		}
 		foreach my $key (sort { $a cmp $b } keys %{$params}) {
 			if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
-				if (defined $params->{$key}) {
-					$self->$key($params->{$key});
-				}
+				$self->$key($params->{$key});
 			}
 		}
 	}
@@ -64,21 +62,20 @@ sub comment {
 
 sub AUTOLOAD {
 	my ($self, $new) = @_;
-	my $type = ref $self or Carp::croak("$self is not an object");
 
 	my $name = $Archive::Har::Entry::Cache::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
+	my $old;
 	if ($name =~ /^_[[:alnum:]]+$/smx) { # private fields
-		my $old = $self->{$name};
+		$old = $self->{$name};
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
-	return;
+	return $old;
 }
 
 sub TO_JSON {
@@ -106,9 +103,6 @@ sub TO_JSON {
 	return $json;
 }
 
-sub DESTROY {
-}
-
 1;
 __END__
 =head1 NAME
@@ -117,7 +111,7 @@ Archive::Har::Entry::Cache - Represents the cache for a single request/response
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -135,6 +129,10 @@ Version 0.07
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Cache object
+
 =head2 before_request
 
 returns the state of the cache before the request
