@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ($class, $params) = @_;
@@ -22,9 +22,7 @@ sub new {
 		}
 		foreach my $key (sort { $a cmp $b } keys %{$params}) {
 			if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
-				if (defined $params->{$key}) {
-					$self->$key($params->{$key});
-				}
+				$self->$key($params->{$key});
 			}
 		}
 	}
@@ -48,7 +46,7 @@ sub last_access {
 			if ($new =~ /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d+(?:\+\d{2}:\d{2}|Z)$/smx) {
 				$self->{lastAccess} = $new;
 			} else {
-				Carp::croak("lastAccess is not formatted correctly:$new");
+				Carp::croak("last_access is not formatted correctly:$new");
 			}
 		} else {
 			$self->{lastAccess} = undef;
@@ -59,7 +57,6 @@ sub last_access {
 	} else {
 		return '0000-00-00T00-00-00';
 	}
-	return $old;
 }
 
 sub etag {
@@ -73,7 +70,6 @@ sub etag {
 	} else {
 		return '';
 	}
-	return $old;
 }
 
 sub hit_count {
@@ -87,7 +83,6 @@ sub hit_count {
 	} else {
 		return 0;
 	}
-	return $old;
 }
 
 sub comment {
@@ -101,21 +96,20 @@ sub comment {
 
 sub AUTOLOAD {
 	my ($self, $new) = @_;
-	my $type = ref $self or Carp::croak("$self is not an object");
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Cache::Request::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
+	my $old;
 	if ($name =~ /^_[[:alnum:]]+$/smx) { # private fields
-		my $old = $self->{$name};
+		$old = $self->{$name};
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
-	return;
+	return $old;
 }
 
 sub TO_JSON {
@@ -147,7 +141,7 @@ Archive::Har::Entry::Cache::Request - Represents a cache request for a cache ins
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -174,6 +168,10 @@ Version 0.07
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Cache Request object
+
 =head2 expires
 
 returns the expiration time of the cache entry
