@@ -1,9 +1,10 @@
 package Archive::Har::Entry::Cookie;
 
+use JSON();
 use warnings;
 use strict;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ($class, $params) = @_;
@@ -32,9 +33,7 @@ sub new {
 		}
 		foreach my $key (sort { $a cmp $b } keys %{$params}) {
 			if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
-				if (defined $params->{$key}) {
-					$self->$key($params->{$key});
-				}
+				$self->$key($params->{$key});
 			}
 		}
 	}
@@ -123,21 +122,20 @@ sub comment {
 
 sub AUTOLOAD {
 	my ($self, $new) = @_;
-	my $type = ref $self or Carp::croak("$self is not an object");
 
 	my $name = $Archive::Har::Entry::Cookie::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
+	my $old;
 	if ($name =~ /^_[[:alnum:]]+$/smx) { # private fields
-		my $old = $self->{$name};
+		$old = $self->{$name};
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
-	return;
+	return $old;
 }
 
 sub TO_JSON {
@@ -155,10 +153,10 @@ sub TO_JSON {
 		$json->{expires} = $self->expires();
 	}
 	if (defined $self->http_only()) {
-		$json->{httpOnly} = $self->http_only() ? \1 : \0;
+		$json->{httpOnly} = $self->http_only() ? JSON::true() : JSON::false();
 	}
 	if (defined $self->secure()) {
-		$json->{secure} = $self->secure() ? \1 : \0;
+		$json->{secure} = $self->secure() ? JSON::true() : JSON::false();
 	}
 	if (defined $self->comment()) {
 		$json->{comment} = $self->comment();
@@ -180,7 +178,7 @@ Archive::Har::Entry::Cookie - Represents a single http cookie object for a reque
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
