@@ -7,7 +7,7 @@ use Archive::Har::Entry::Header();
 use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Response::Content();
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ($class, $params) = @_;
@@ -36,9 +36,7 @@ sub new {
 		}
 		foreach my $key (sort { $a cmp $b } keys %{$params}) {
 			if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
-				if (defined $params->{$key}) {
-					$self->$key($params->{$key});
-				}
+				$self->$key($params->{$key});
 			}
 		}
 	}
@@ -164,21 +162,20 @@ sub body_size {
 
 sub AUTOLOAD {
 	my ($self, $new) = @_;
-	my $type = ref $self or Carp::croak("$self is not an object");
 
 	my $name = $Archive::Har::Entry::Response::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
+	my $old;
 	if ($name =~ /^_[[:alnum:]]+$/smx) { # private fields
-		my $old = $self->{$name};
+		$old = $self->{$name};
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
-	return;
+	return $old;
 }
 
 sub TO_JSON {
@@ -220,7 +217,7 @@ Archive::Har::Entry::Response - Represents a single http response inside the HTT
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
